@@ -164,8 +164,8 @@ class LightningModel(pl.LightningModule):
         self.model = model
         self.tokenizer = tokenizer
         self.output = output
-        self.val_acc = Accuracy()
-        self.train_acc = Accuracy()
+        #self.val_acc = Accuracy()
+        #self.train_acc = Accuracy()
 
     def forward(self, input_ids, attention_mask, decoder_attention_mask, labels=None):
         """ forward step """
